"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const theme_1 = require("../Styles/theme");
const { width: WINDOW_WIDTH, height: WINDOW_HEIGHT } = react_native_1.Dimensions.get('window');
const MAX_SCROLL_HEIGHT = 300;
const PickerView = props => {
    const { dataSource, selectedIndex, itemHeight, onChange } = props;
    const [showPickerItem, setShowPickItem] = react_1.useState(false);
    // ScrollView 在Modal中会影响Modal的高度计算，先让容器渲染出来，再渲染ScrollView
    react_1.useEffect(() => {
        setTimeout(() => {
            setShowPickItem(true);
        }, 50);
    }, []);
    const height = Math.min(MAX_SCROLL_HEIGHT, WINDOW_HEIGHT / 3);
    const padding = (height - itemHeight) / 2;
    const highlightStyle = {
        top: padding,
        height: itemHeight,
        width: WINDOW_WIDTH,
        borderTopColor: theme_1.Theme.borderColor,
        borderBottomColor: theme_1.Theme.borderColor,
        borderTopWidth: theme_1.Theme.borderWidthSm,
        borderBottomWidth: theme_1.Theme.borderWidthSm,
    };
    return (react_1.default.createElement(react_native_1.View, { style: [styles.container, { height }] }, showPickerItem
        ? dataSource.map((item, index) => (react_1.default.createElement(react_native_1.View, { key: index, style: [styles.picker] },
            react_1.default.createElement(react_native_1.View, { style: [styles.highlight, highlightStyle] }),
            react_1.default.createElement(PickerItem, { dataSource: item, selectedIndex: selectedIndex[index], itemHeight: itemHeight, onChange: i => {
                    const data = [...selectedIndex];
                    data[index] = i;
                    onChange && onChange(data);
                } }))))
        : null));
};
exports.default = PickerView;
const PickerItem = props => {
    const { dataSource, selectedIndex, itemHeight, onChange } = props;
    const [activeIndex, setActiveIndex] = react_1.useState(selectedIndex);
    const $scroll = react_1.useRef(null);
    const isScrolling = react_1.useRef(false);
    const height = Math.min(MAX_SCROLL_HEIGHT, WINDOW_HEIGHT / 3);
    const padding = (height - itemHeight) / 2;
    const onMomentumScrollBegin = () => {
        isScrolling.current = true;
    };
    const onMomentumScrollEnd = (event) => {
        isScrolling.current = false;
        if (!isScrolling.current) {
            scrollToFix(event.nativeEvent.contentOffset.y);
        }
    };
    const scrollToFix = (y) => {
        const index = Math.round(y / itemHeight);
        const _y = index * itemHeight;
        if (y !== _y) {
            $scroll.current?.scrollTo({
                y: _y,
                animated: true,
            });
        }
        onChange && onChange(index);
    };
    react_1.useEffect(() => {
        const y = selectedIndex * itemHeight;
        $scroll.current?.scrollTo({
            y,
            animated: true,
        });
        // 高度或者index变化都需要滚动
    }, [itemHeight, selectedIndex]);
    return (react_1.default.createElement(react_native_1.ScrollView, { ref: $scroll, style: styles.scrollView, contentContainerStyle: styles.scrollViewContent, bounces: false, showsVerticalScrollIndicator: false, nestedScrollEnabled: true, decelerationRate: "normal", onMomentumScrollBegin: onMomentumScrollBegin, onMomentumScrollEnd: onMomentumScrollEnd, onScroll: e => {
            const index = Math.round(e.nativeEvent.contentOffset.y / itemHeight);
            setActiveIndex(index);
        } },
        react_1.default.createElement(react_native_1.View, { style: [styles.placeholder, { height: padding }] }),
        dataSource.map((i, idx) => (react_1.default.createElement(react_native_1.View, { key: idx, style: [styles.pickerItem, { height: itemHeight }] },
            react_1.default.createElement(react_native_1.Text, { style: [styles.pickText, activeIndex === idx && styles.activeText] }, i)))),
        react_1.default.createElement(react_native_1.View, { style: [styles.placeholder, { height: padding }] })));
};
const styles = react_native_1.StyleSheet.create({
    container: {
        flexDirection: 'row',
        justifyContent: 'space-between',
    },
    picker: {
        flex: 1,
    },
    highlight: {
        position: 'absolute',
    },
    scrollView: {
        width: '100%',
    },
    scrollViewContent: {
        alignItems: 'center',
    },
    placeholder: {
        flex: 1,
    },
    pickerItem: {
        justifyContent: 'center',
    },
    pickText: {
        fontSize: theme_1.Theme.fontSizeCaption,
        color: theme_1.Theme.colorTextCaption,
    },
    activeText: {
        color: theme_1.Theme.colorTextParagraph,
    },
});
